# dflow-phonon
使用方法：

pip install --index-url https://pypi.org/simple/ --no-deps dflow-phonon

之后进入一个example文件夹，填写global.json

如果调用VASP： dflowphonon --vasp
如果使用DP势函数： dflowphonon --dp
如果调用ABACUS：dflowphonon --abacus

然后在https://workflows.deepmodeling.com 监控任务进程
